==> ejc-production-api-3.0.0-20220624.133937-190-sources.jar: com/ejianc/business/production/task/api/DistributeCarManageApi.java <==
package com.ejianc.business.production.task.api;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.production.task.hystrix.DistributeCarManageHystrix;
import com.ejianc.business.production.task.hystrix.ProductionTaskHystrix;
import com.ejianc.business.production.task.vo.UnitdistributionVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

/**
 * @authoer:禹鹏杰
 * @createDate:2022/6/24
 * @description:中东派车管理相关接口
 */
@FeignClient(name= "ejc-production-web", url="${common.env.feign-client-url}", path="ejc-production-web", fallback = DistributeCarManageHystrix.class)
public interface DistributeCarManageApi {
    /**
     * 查询所有分配机组数据
     * @param param
     * @return
     */
    @RequestMapping(value = "/api/production/DistributeCarManageApi/queryList", method = RequestMethod.POST)
    @ResponseBody
    CommonResponse<IPage<UnitdistributionVO>> queryList(@RequestBody QueryParam param);

    /**
     * 机组分配车辆保存
     * @param saveOrUpdateVO
     * @return
     */
    @RequestMapping(value = "/api/production/DistributeCarManageApi/savedistributecar", method = RequestMethod.POST)
    @ResponseBody
    CommonResponse<IPage<com.ejianc.business.production.task.vo.UnitdistributionVO>> save(UnitdistributionVO saveOrUpdateVO);
}

==> ejc-production-api-3.0.0-20220627.023505-193-sources.jar: com/ejianc/business/production/task/api/DistributeCarManageApi.java <==
package com.ejianc.business.production.task.api;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.production.task.hystrix.DistributeCarManageHystrix;
import com.ejianc.business.production.task.hystrix.ProductionTaskHystrix;
import com.ejianc.business.production.task.vo.UnitdistributionVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

/**
 * @authoer:禹鹏杰
 * @createDate:2022/6/24
 * @description:中东派车管理相关接口
 */
@FeignClient(name= "ejc-production-web", url="${common.env.feign-client-url}", path="ejc-production-web", fallback = DistributeCarManageHystrix.class)
public interface DistributeCarManageApi {
    /**
     * 查询所有分配机组数据
     * @param param
     * @return
     */
    @RequestMapping(value = "/api/production/distributecarmanageApi/queryList", method = RequestMethod.POST)
    @ResponseBody
    CommonResponse<IPage<UnitdistributionVO>> queryList(@RequestBody QueryParam param);

    /**
     * 机组分配车辆保存
     * @param saveOrUpdateVO
     * @return
     */
    @RequestMapping(value = "/api/production/DistributeCarManageApi/savedistributecar", method = RequestMethod.POST)
    @ResponseBody
    CommonResponse<IPage<com.ejianc.business.production.task.vo.UnitdistributionVO>> save(UnitdistributionVO saveOrUpdateVO);
}
